==> gradle-8.6-all.zip: org/gradle/kotlin/dsl/GradleApiKotlinDslExtensions_8tlt3ezu4cu8d6afi709nfjgn.kt <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

@file:Suppress(
    "unused",
    "nothing_to_inline",
    "useless_cast",
    "unchecked_cast",
    "extension_shadowed_by_member",
    "redundant_projection",
    "RemoveRedundantBackticks",
    "ObjectPropertyName",
    "deprecation"
)
@file:org.gradle.api.Generated

/* ktlint-disable */

package org.gradle.kotlin.dsl


           /**
            * Kotlin extension function for [org.gradle.api.tasks.WriteProperties.setProperties].
            *
            * @see org.gradle.api.tasks.WriteProperties.setProperties
* @since 3.3
            */
inline fun org.gradle.api.tasks.WriteProperties.`setProperties`(vararg `properties`: Pair<String, Any?>): Unit =
    `setProperties`(mapOf(*`properties`))


           /**
            * Kotlin extension function for [org.gradle.api.tasks.WriteProperties.properties].
            *
            * @see org.gradle.api.tasks.WriteProperties.properties
* @since 3.4
            */
inline fun org.gradle.api.tasks.WriteProperties.`properties`(vararg `properties`: Pair<String, Any?>): Unit =
    `properties`(mapOf(*`properties`))

==> gradle-9.3.0-20251113002235+0000-all.zip: org/gradle/kotlin/dsl/GradleApiKotlinDslExtensions_8tlt3ezu4cu8d6afi709nfjgn.kt <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

@file:Suppress(
    "unused",
    "nothing_to_inline",
    "useless_cast",
    "unchecked_cast",
    "extension_shadowed_by_member",
    "redundant_projection",
    "RemoveRedundantBackticks",
    "ObjectPropertyName",
    "deprecation",
    "detekt:all"
)
@file:org.gradle.api.Generated

package org.gradle.kotlin.dsl


/**
 * Kotlin extension function for [org.gradle.api.tasks.WriteProperties.setProperties].
 *
 * @see org.gradle.api.tasks.WriteProperties.setProperties
 * @since 3.3
 */
inline fun org.gradle.api.tasks.WriteProperties.`setProperties`(vararg `properties`: Pair<String, Any>): Unit =
    `setProperties`(mapOf(*`properties`))


/**
 * Kotlin extension function for [org.gradle.api.tasks.WriteProperties.properties].
 *
 * @see org.gradle.api.tasks.WriteProperties.properties
 * @since 3.4
 */
inline fun org.gradle.api.tasks.WriteProperties.`properties`(vararg `properties`: Pair<String, Any>): Unit =
    `properties`(mapOf(*`properties`))
